AppMetadata class

Metadata about an application connecting to the indexer.

Constructors

AppMetadata({required Uint8List id, required String name, required String description, required String serviceUrl, String? logoUrl, String? callbackUrl})
const

Properties

callbackUrl String?
final
description String
final
hashCode int
The hash code for this object.
no setteroverride
id Uint8List
final
logoUrl String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUrl String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override