ShardProgress class

Progress information about a successfully uploaded or downloaded shard.

Constructors

ShardProgress({required String hostKey, required int shardSize, required int shardIndex, required int slabIndex, required double elapsedMs})
const

Properties

elapsedMs double
final
hashCode int
The hash code for this object.
no setteroverride
hostKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shardIndex int
final
shardSize int
final
slabIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override